@@ -127,6 +127,10 @@ static void doom3_init_maps(enum server_type);
 static size_t doom3_get_mapshot(struct server* s, guchar** buf);
 static gboolean doom3_has_map(struct server* s);
 
+static void quake4_init_maps(enum server_type);
+static size_t quake4_get_mapshot(struct server* s, guchar** buf);
+static gboolean quake4_has_map(struct server* s);
+
 static void unreal_init_maps(enum server_type);
 static gboolean unreal_has_map(struct server* s);
 
@@ -156,6 +160,7 @@ static struct quake_private mohaa_private;
 static struct quake_private cod_private;
 static struct quake_private jk3_private;
 static struct quake_private doom3_private;
+static struct quake_private quake4_private;
 
 #include "games.c"
 
@@ -448,11 +453,19 @@ static struct player *descent3_parse_player (char *token[], int n, struct server
 
 static struct player *q3_parse_player (char *token[], int n, struct server *s) {
   struct player *player = NULL;
+  char* clan = NULL;
+  unsigned clanlen = 0;
 
   if (n < 3)
     return NULL;
 
-  player = g_malloc0 (sizeof (struct player) + strlen (token[0]) + 1);
+  if(n > 3 && strcmp(token[3], "0"))
+  {
+    clan = token[3];
+    clanlen = strlen(clan)+1;
+  }
+
+  player = g_malloc0 (sizeof (struct player) + strlen (token[0]) + 1 + clanlen);
   player->time  = -1;
   player->frags = strtosh (token[1]);
   player->ping  = strtosh (token[2]);
@@ -462,6 +475,13 @@ static struct player *q3_parse_player (char *token[], int n, struct server *s) {
   player->name = (char *) player + sizeof (struct player);
   q3_unescape (player->name, token[0]);
 
+  // show clan name in model column
+  if(clan)
+  {
+    player->model = (char *) player + sizeof (struct player) + strlen(player->name) + 1; 
+    strcpy(player->model, clan);
+  }
+
   return player;
 }
 
@@ -1076,6 +1096,20 @@ static char *q3a_wop_gametypes[MAX_Q3A_WOP_TYPES] = {
   "BigBalloon (BB)" // 8
 };
 
+#define MAX_Q3A_EXCESSIVEPLUS_TYPES 10
+static char *q3a_excessiveplus_gametypes[MAX_Q3A_EXCESSIVEPLUS_TYPES] = {
+  "FFA",               /* 0 = Free for All */
+  "1v1",               /* 1 = Tournament */
+  NULL,                /* 2 = Single Player */
+  "TDM",               /* 3 = Team Deathmatch */
+  "CTF",               /* 4 = Capture the Flag */
+  "RTF",               /* 5 = Return the Flag */
+  "One Flag CTF",      /* 6 = One Flag Capture the Flag */
+  "Clan Arena",        /* 7 = Clan Arena */
+  "Freeze Tag",        /* 8 = Freeze Tag */
+  "Protect the Leader" /* 9 = Protect the Leader */
+};
+
 #define MAX_WOLF_TYPES 9
 static char *wolf_gametypes[MAX_WOLF_TYPES] = {
   NULL,			// 0 - Unknown
@@ -1236,6 +1270,11 @@ struct q3a_gametype_s q3a_gametype_map[] =
     q3a_wop_gametypes,
     MAX_Q3A_WOP_TYPES
   },
+  {
+    "excessiveplus",
+    q3a_excessiveplus_gametypes,
+    MAX_Q3A_EXCESSIVEPLUS_TYPES
+  },
   {
     NULL,
     NULL,
@@ -1381,6 +1420,40 @@ static void q3_analyze_serverinfo (struct server *s) {
   if ((games[s->type].flags & GAME_SPECTATE) != 0)
     s->flags |= SERVER_SPECTATE;
 
+  // check if it's really a q3 server. We need to do that first to determine
+  // whether the server protcol for that game is compatible
+  for (info_ptr = s->info; info_ptr && *info_ptr; info_ptr += 2) {
+    if (strcmp (*info_ptr, "version" ) == 0) {
+      if(!strncmp(info_ptr[1],"Q3",2))
+      {
+	s->type=Q3_SERVER;
+      }
+      else if(!strncmp(info_ptr[1],"Wolf",4))
+      {
+	s->type=WO_SERVER;
+      }
+      else if(!strncmp(info_ptr[1],"ET 2",4) || !strncmp(info_ptr[1],"ETTV ",5))
+      {
+	s->type=WOET_SERVER;
+      }
+      // voyager elite force
+      else if(!strncmp(info_ptr[1],"ST:V HM",7))
+      {
+	s->type=EF_SERVER;
+      }
+      else if(!strncmp(info_ptr[1],"Medal",5))
+      {
+	s->type=MOHAA_SERVER;
+      }
+      else if(!strncmp(info_ptr[1],"SOF2MP",6))
+      {
+	s->type=SOF2S_SERVER;
+      }
+
+      break;
+    }
+  }
+
   for (info_ptr = s->info; info_ptr && *info_ptr; info_ptr += 2) {
  
     /*
@@ -1410,33 +1483,6 @@ static void q3_analyze_serverinfo (struct server *s) {
       } else {
 	s->sv_os = '?';
       }
-
-      // check if it's really a q3 server
-      if(!strncmp(info_ptr[1],"Q3",2))
-      {
-	s->type=Q3_SERVER;
-      }
-      else if(!strncmp(info_ptr[1],"Wolf",4))
-      {
-	s->type=WO_SERVER;
-      }
-      else if(!strncmp(info_ptr[1],"ET 2",4))
-      {
-	s->type=WOET_SERVER;
-      }
-      // voyager elite force
-      else if(!strncmp(info_ptr[1],"ST:V HM",7))
-      {
-	s->type=EF_SERVER;
-      }
-      else if(!strncmp(info_ptr[1],"Medal",5))
-      {
-	s->type=MOHAA_SERVER;
-      }
-      else if(!strncmp(info_ptr[1],"SOF2MP",6))
-      {
-	s->type=SOF2S_SERVER;
-      }
     }
     
     else if (!s->gametype && strcmp (*info_ptr, "g_gametype") == 0) {
@@ -1558,6 +1604,9 @@ static void doom3_analyze_serverinfo (struct server *s) {
 	s->flags |= SERVER_INCOMPATIBLE;
       }
     }
+    else if (!strcmp(*info_ptr, "sv_punkbuster") && info_ptr[1] && info_ptr[1][0] == '1') {
+      s->flags |= SERVER_PUNKBUSTER;
+    }
   }
 
   if(fs_game)
@@ -1918,6 +1967,7 @@ out:
   return ret;
 }
 
+#if 0
 static int is_dir (const char *dir, const char *gamedir) {
   struct stat stat_buf;
   char *path;
@@ -1930,6 +1980,7 @@ static int is_dir (const char *dir, const char *gamedir) {
   }
   return res;
 }
+#endif
 
 static int q1_exec_generic (const struct condef *con, int forkit) {
   char *argv[32];
@@ -2522,7 +2573,7 @@ static int ut_exec (const struct condef *con, int forkit) {
 // Pass server IP address first otherwise it won't work.
 // Make sure ut/ut script (from installed game) contains
 // exec "./ut-bin" $* -log and not -log $* at the end
-// otherwise XQF you can not connect via the command line!
+// otherwise XQF can not connect via the command line!
 
   if(g->flags & GAME_LAUNCH_HOSTPORT) {
     // go through all server rules
@@ -3223,6 +3274,18 @@ static void quake_save_info (FILE *f, struct server *s) {
 		 p->ping);
 	break;
 
+      case Q4_SERVER:
+	fprintf (f, 
+		 "%s" QSTAT_DELIM_STR 
+		 "%d" QSTAT_DELIM_STR 
+		 "%d" QSTAT_DELIM_STR 
+		 "%s\n",
+		 (p->name)? p->name : "",
+		 p->frags,
+		 p->ping,
+		 p->model?p->model:"0");
+	break;
+
       default:
 	fprintf (f, 
 		 "%s" QSTAT_DELIM_STR 
@@ -3337,6 +3400,23 @@ static void doom3_init_maps(enum server_type type)
   }
 }
 
+static void quake4_init_maps(enum server_type type)
+{
+  struct quake_private* pd = NULL;
+
+  pd = (struct quake_private*)games[type].pd;
+  g_return_if_fail(pd!=NULL);
+  
+  q3_clear_maps(pd->maphash); // important to avoid memleak when called second time
+  pd->maphash = q3_init_maphash();
+  findquake4maps(pd->maphash,games[type].real_dir);
+
+  if(games[type].real_home && access(games[type].real_home, R_OK) == 0)
+  {
+    findquake4maps(pd->maphash, games[type].real_home);
+  }
+}
+
 static void unreal_init_maps(enum server_type type)
 {
   struct unreal_private* pd = NULL;
@@ -3392,6 +3472,10 @@ static gboolean doom3_has_map(struct server* s)
   return doom3_lookup_map(hash,s->map);
 }
 
+static gboolean quake4_has_map(struct server* s)
+{
+  return doom3_has_map(s);
+}
 
 static size_t q3_get_mapshot(struct server* s, guchar** buf)
 {
@@ -3431,6 +3515,11 @@ static size_t doom3_get_mapshot(struct server* s, guchar** buf)
   return doom3_lookup_mapshot(hash,s->map, buf);
 }
 
+static size_t quake4_get_mapshot(struct server* s, guchar** buf)
+{
+  return doom3_get_mapshot(s, buf);
+}
+
 static gboolean unreal_has_map(struct server* s)
 {
   struct unreal_private* pd = NULL;
