@@ -46,6 +46,7 @@
 #include "xpm/q1.xpm"
 #include "xpm/q2.xpm"
 #include "xpm/q3.xpm"
+#include "xpm/q4.xpm"
 #include "xpm/wo.xpm"
 #include "xpm/et.xpm"
 #include "xpm/stvef.xpm"
@@ -67,6 +68,7 @@
 #include "xpm/ut2.xpm"
 #include "xpm/ut2004.xpm"
 #include "xpm/netp.xpm"
+#include "xpm/nexuiz.xpm"
 
 #include "xpm/gamespy3d.xpm"
 #include "xpm/ssam.xpm"
@@ -93,6 +95,7 @@
 #include "xpm/buddy-blue.xpm"
 
 #include "xpm/error.xpm"
+#include "xpm/delete.xpm"
 
 #include "xpm/server-na.xpm"
 #include "xpm/server-up.xpm"
@@ -129,6 +132,7 @@ struct pixmap group_pix[3];
 struct pixmap buddy_pix[9];
 
 struct pixmap error_pix;
+struct pixmap delete_pix;
 
 struct pixmap server_status[5];
 struct pixmap locked_pix;
@@ -222,6 +226,7 @@ void free_pixmaps (void)
     free_pixmap (&buddy_pix[i]);
 
   free_pixmap (&error_pix);
+  free_pixmap (&delete_pix);
 
   for (i = 0; i < 5; i++)
     free_pixmap (&server_status[i]);
@@ -349,6 +354,7 @@ void init_pixmaps (GtkWidget *window)
   create_pixmap (window, "server_error.xpm", &server_status[4]);
 
   create_pixmap (window, "error.xpm", &error_pix);
+  create_pixmap (window, "delete.xpm", &delete_pix);
   create_pixmap (window, "locked.xpm", &locked_pix);
   create_pixmap (window, "punkbuster.xpm", &punkbuster_pix);
   cat_pixmaps(window, &locked_punkbuster_pix, &punkbuster_pix, &locked_pix);
